4 ms·
I think most of the SSE slowness is because the weird static vec::add that uses pass by value, try changing that to pass by reference.
by detrino 12y ago
I think most of the SSE slowness is because the weird static vec::add that uses pass by value, try changing that to pass by reference.
- ridiculous_fish 12y agoWow, you're right! That improves the time from 7.11 to 3.94 seconds. I was skeptical because 'add' is inlined, which I expected would eliminate pointless copies, but I guess not!